<#-- Description of uses report for DOW Chemicals main template file -->
<#-- Import common macros and functions -->
<#compress>
<#import "macros_common_general.ftl" as com>
<#-- Initialize common variables -->
<@com.initializeMainVariables/>
<#assign referenceSubstance = iuclid.getDocumentForKey(_subject.ReferenceSubstance.ReferenceSubstance) />
<#assign ownerLegalEntity = iuclid.getDocumentForKey(_subject.OwnerLegalEntity) />
<#assign locale = "en" />
<#-- Print the headears for each column -->
Dossier UUID,Use UUID,Identification UUID,CAS number,EC number,LCS,Short Title,Navigation Name,ERC,PROC,PC,AC,LE
<#compress>
<#-- ERCs -->
<#-- Manufacture records 3.5.1 -->
<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "Manufacturer") />
	<#if recordList?has_content>
		<#list recordList as record>
			<#assign useName = record.Manufacture.IdentifiedUseName />
			<#assign docName = record.Manufacture />
				<@tableRowForUses record useName docName record.name record.documentKey.uuid />
		</#list>
	</#if>

<#-- Formulation records 3.5.2 -->
<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "Formulation") />
	<#if recordList?has_content>
		<#list recordList as record>
			<#assign useName = record.Formulation.IdentifiedUseName />
			<#assign docName = record.Formulation />
			<@tableRowForUses record useName docName record.name record.documentKey.uuid />
					
		</#list>
	</#if>

<#-- UseAtIndustrialSites records 3.5.3 -->
<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "UseAtIndustrialSites") />
	<#if recordList?has_content>
		<#list recordList as record>
			<#assign useName = record.UsesAtIndustrialSites.IdentifiedUseName />
			<#assign docName = record.UsesAtIndustrialSites />
			<@tableRowForUses record useName docName record.name record.documentKey.uuid />
		
		</#list>
	</#if>

<#-- UseProfesional workers records 3.5.4 -->
<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "ProfessionalWorkers") />
	<#if recordList?has_content>
		<#list recordList as record>
			<#assign useName = record.UsesByProfessionalWorkers.IdentifiedUseName />
			<#assign docName = record.UsesByProfessionalWorkers />
			<@tableRowForUses record useName docName record.name record.documentKey.uuid />
					
		</#list>
	</#if>

<#-- Consumer records 3.5.5 -->
<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "ConsumerUses") />
	<#if recordList?has_content>
		<#list recordList as record>
			<#assign useName = record.ConsumerUses.IdentifiedUseName />
			<#assign docName = record.ConsumerUses />
			<@tableRowForUses record useName docName record.name record.documentKey.uuid />
						
		</#list>
	</#if>	

<#-- Service Life records 3.5.6 -->
<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "ArticleServiceLife") />
	<#if recordList?has_content>
		<#list recordList as record>
			<#assign useName = record.ArticleServiceLife.IdentifiedUseName />
			<#assign docName = record.ArticleServiceLife />
			<@tableRowForUses record useName docName record.name record.documentKey.uuid />
					
		</#list>
	</#if>
	
</#compress>
<#-- Macros and functions -->
<#-- Macro for listing uses in a table -->
<#macro tableRowForUses record useName docName recordName="" recordUUID="">	
<#compress>
"${record.documentKey.snapshotUuid}","${record.documentKey.uuid}","${_subject.documentKey.uuid}",<@CASNumber referenceSubstance />,<@com.inventoryECNumber referenceSubstance/>,<@hardcodedRecordNames record/>,"${recordName?replace(",","")}","${useName?replace(",","")}",<@contributingActivityListERC docName/>,<@contributingActivityListPROC record docName/>,<@productCategory record docName/>,<@articleCategory record docName/>,<@legalEntityName ownerLegalEntity/>
</#compress>
</#macro>

<#-- Macro for Legal entity -->
<#macro legalEntityName ownerLegalEntity>
<#compress>
<#if ownerLegalEntity?has_content>
	"${ownerLegalEntity.GeneralInfo.LegalEntityName?replace(",","")}"
<#else></#if>
</#compress>
</#macro>

<#-- Macro for ERCs in use records -->
<#macro contributingActivityListERC docName>
<@compress single_line=true>
	<#if docName?has_content>	
		<#list docName.ContributingActivityTechniqueForTheEnvironment as contributingActivityEnvironment>			
			<#if contributingActivityEnvironment.EnvironmentalReleaseCategoryERC?has_content>
				<#assign erc><@com.picklistMultiple contributingActivityEnvironment.EnvironmentalReleaseCategoryERC/></#assign>	
				${erc?replace(",","")}
			</#if>
		</#list>
  	</#if>
</@compress>
</#macro>

<#-- Macro for PROCs in use records -->
<#macro contributingActivityListPROC record docName>
<@compress single_line=true>
	<#assign docDefId = record.documentType +"."+ record.documentSubType/>
	<#if docDefId!="FLEXIBLE_RECORD.ConsumerUses">	
		<#list docName.ContributingActivityTechniqueForWorkers as contributingActivityWorkers>
			<#if contributingActivityWorkers.ProcessCategoryPROC?has_content>
				<#assign proc><@com.picklistMultiple contributingActivityWorkers.ProcessCategoryPROC/></#assign>	
				${proc?replace(",","")}
			</#if>	
		</#list>
  	</#if>
</@compress>
</#macro>

<#macro articleCategory record docName>
<@compress single_line=true>
	<#assign docDefId = record.documentType +"."+ record.documentSubType/>
	<#if docDefId="FLEXIBLE_RECORD.ArticleServiceLife">	
		<#if docName.ArticleCategories?has_content>
			<#assign ac><@com.picklistMultiple docName.ArticleCategories /></#assign>	
			${ac?replace(",","")}
		</#if>	
  	</#if>
</@compress>
</#macro>

<#macro productCategory record docName>
<@compress single_line=true>
	<#assign docDefId = record.documentType +"."+ record.documentSubType/>
	<#if docDefId!="FLEXIBLE_RECORD.Manufacturer">
	<#if docDefId!="FLEXIBLE_RECORD.ArticleServiceLife">
	<#if docDefId!="FLEXIBLE_RECORD.ConsumerUses">
		<#if docName.ProductCategories?has_content>
			<#assign pc><@com.picklistMultiple docName.ProductCategories /></#assign>	
			${pc?replace(",","")}
		</#if>	
		<#elseif docDefId="FLEXIBLE_RECORD.ConsumerUses">
			<#list docName.ContributingActivityTechniqueForConsumers as activityForConsumers>
				<#if activityForConsumers.ProductCategoryPC?has_content>
					<#assign pc><@com.picklistMultiple activityForConsumers.ProductCategoryPC /></#assign>
					${pc?replace(",","")}
				</#if>
			</#list>
	</#if>
	</#if>
  	</#if>
</@compress>
</#macro>

<#-- Macro for CAS number -->
<#macro CASNumber referenceSubstance>
<#compress>
	<#if referenceSubstance?has_content>
		<@com.casNumber referenceSubstance />			
	</#if>
</#compress>
</#macro>

<#-- Macro for hardcoding record names -->
<#macro hardcodedRecordNames record>
<#compress>
<#assign docDefId = record.documentType +"."+ record.documentSubType/>
	<#if docDefId=="FLEXIBLE_RECORD.Manufacturer">
	M
		<#elseif docDefId=="FLEXIBLE_RECORD.Formulation"/>
		F
		<#elseif docDefId=="FLEXIBLE_RECORD.UseAtIndustrialSites"/>
		IS
		<#elseif docDefId=="FLEXIBLE_RECORD.ProfessionalWorkers"/>
		PW
		<#elseif docDefId=="FLEXIBLE_RECORD.ConsumerUses"/>
		C
		<#elseif docDefId=="FLEXIBLE_RECORD.ArticleServiceLife"/>
		SL
	</#if>
</#compress>
</#macro>
</#compress>








